changeset 96541:d39625535543

(vc-dir-refresh): Only update files.
author Dan Nicolaescu <dann@ics.uci.edu>
date Mon, 07 Jul 2008 16:59:39 +0000
parents f534da0cc0ea
children 4b75a9224462
files lisp/ChangeLog lisp/vc-dir.el
diffstat 2 files changed, 6 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Mon Jul 07 16:35:48 2008 +0000
+++ b/lisp/ChangeLog	Mon Jul 07 16:59:39 2008 +0000
@@ -1,5 +1,7 @@
 2008-07-07  Dan Nicolaescu  <dann@ics.uci.edu>
 
+	* vc-dir.el (vc-dir-refresh): Only update files.
+
 	* vc-git.el (vc-git--ls-files-state): Remove unused function.
 
 	* vc-bzr.el (vc-bzr-after-dir-status): Deal with execute bit changes.
--- a/lisp/vc-dir.el	Mon Jul 07 16:35:48 2008 +0000
+++ b/lisp/vc-dir.el	Mon Jul 07 16:59:39 2008 +0000
@@ -955,8 +955,10 @@
       (unless (buffer-live-p vc-dir-process-buffer)
         (setq vc-dir-process-buffer
               (generate-new-buffer (format " *VC-%s* tmp status" backend))))
-      ;; set the needs-update flag on all entries
-      (ewoc-map (lambda (info) (setf (vc-dir-fileinfo->needs-update info) t) nil)
+      ;; set the needs-update flag on all non-directory entries
+      (ewoc-map (lambda (info)
+		  (unless (vc-dir-fileinfo->directory info)
+		    (setf (vc-dir-fileinfo->needs-update info) t) nil))
                 vc-ewoc)
       (lexical-let ((buffer (current-buffer)))
         (with-current-buffer vc-dir-process-buffer